==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/cs.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Je dostupná {version}. Přečtěte si více informací jak aktualizovat.",
    "Apps with available updates" : "Aplikace s dostupnými aktualizacemi",
    "Open updater" : "Otevřít aktualizátor",
    "Your version is up to date." : "Používáte nejnovější verzi.",
    "A non-default update server is in use to be checked for updates:" : "Pro kontrolu aktualizací se používá jiný než výchozí server:",
    "Update channel:" : "Aktualizovat kanál:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vždy můžete aktualizovat na novější verzi / experimentální kanál. Poté ale nelze nikdy provést downgrade zpět na nižší stabilní kanál.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Všimněte si, že po vydání nové verze může chvíli trvat, než se zde objeví. Distribuujeme nové verze průběžně rozložené v čase mezi naše uživatele a pokud  jsou nalezeny problémy někdy danou verzi přeskočíme.",
    "Notify members of the following groups about available updates:" : "Upozorňovat členy následujících skupin na dostupné aktualizace:",
    "Only notification for app updates are available." : "Je možné pouze upozornění na dostupné aktualizace aplikací.",
    "The selected update channel does not support updates of the server." : "Vybraný kanál aktualizací nepodporuje aktualizace serveru.",
    "A new version is available: <strong>{newVersionString}</strong>" : "K dispozici je nová verze: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Zkontrolováno {lastCheckedDate}",
    "Could not start updater, please try the manual update" : "Nepodařilo se spustit aktualizátor, zkuste ruční aktualizaci",
    "Update notifications" : "Aktualizovat upozornění",
    "Channel updated" : "Kanál aktualizován",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizační server nebyl dosažen %d dní pro kontrolu aktualizací.",
    "Please check the Nextcloud and server log files for errors." : "Po chybách se podívejte v protokolech Nextcloudu a webového serveru.",
    "Update to %1$s is available." : "Je dostupná aktualizace na %1$s.",
    "Update for %1$s to version %2$s is available." : "Je dostupná aktualizace pro %1$s na verzi %2$s.",
    "Update for {app} to version %s is available." : "Pro {app} je dostupná aktualizace na verzi %s.",
    "Update notification" : "Upozornění na aktualizaci",
    "A new version is available: %s" : "Je dostupná nová verze: %s",
    "Download now" : "Stáhnout nyní",
    "Checked on %s" : "Zkontrolováno %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Zvolený kanál aktualizací označuje dedikovaná upozornění pro server za zastaralá.",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizací ještě neskončila. Obnovte stránku."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/cs.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "Je dostupná {version}. Přečtěte si více informací jak aktualizovat.",
    "Apps with available updates" : "Aplikace s dostupnými aktualizacemi",
    "Open updater" : "Otevřít aktualizátor",
    "Your version is up to date." : "Používáte nejnovější verzi.",
    "A non-default update server is in use to be checked for updates:" : "Pro kontrolu aktualizací se používá jiný než výchozí server:",
    "Update channel:" : "Aktualizovat kanál:",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Vždy můžete aktualizovat na novější verzi / experimentální kanál. Poté ale nelze nikdy provést downgrade zpět na nižší stabilní kanál.",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Všimněte si, že po vydání nové verze může chvíli trvat, než se zde objeví. Distribuujeme nové verze průběžně rozložené v čase mezi naše uživatele a pokud  jsou nalezeny problémy někdy danou verzi přeskočíme.",
    "Notify members of the following groups about available updates:" : "Upozorňovat členy následujících skupin na dostupné aktualizace:",
    "Only notification for app updates are available." : "Je možné pouze upozornění na dostupné aktualizace aplikací.",
    "The selected update channel does not support updates of the server." : "Vybraný kanál aktualizací nepodporuje aktualizace serveru.",
    "A new version is available: <strong>{newVersionString}</strong>" : "K dispozici je nová verze: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Zkontrolováno {lastCheckedDate}",
    "Checking apps for compatible updates" : "Zjišťuje se dostupnost kompatibilních aktualizací aplikací",
    "Could not start updater, please try the manual update" : "Nepodařilo se spustit aktualizátor, zkuste ruční aktualizaci",
    "Update notifications" : "Aktualizovat upozornění",
    "Channel updated" : "Kanál aktualizován",
    "The update server could not be reached since %d days to check for new updates." : "Aktualizační server nebyl dosažen %d dní pro kontrolu aktualizací.",
    "Please check the Nextcloud and server log files for errors." : "Po chybách se podívejte v protokolech Nextcloudu a webového serveru.",
    "Update to %1$s is available." : "Je dostupná aktualizace na %1$s.",
    "Update for %1$s to version %2$s is available." : "Je dostupná aktualizace pro %1$s na verzi %2$s.",
    "Update for {app} to version %s is available." : "Pro {app} je dostupná aktualizace na verzi %s.",
    "Update notification" : "Upozornění na aktualizaci",
    "A new version is available: %s" : "Je dostupná nová verze: %s",
    "Download now" : "Stáhnout nyní",
    "Checked on %s" : "Zkontrolováno %s",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Zvolený kanál aktualizací označuje dedikovaná upozornění pro server za zastaralá.",
    "The update check is not yet finished. Please refresh the page." : "Kontrola aktualizací ještě neskončila. Obnovte stránku."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
